==> medmodels-0.0.1a1.tar.gz: medmodels-0.0.1a1/README.md <==
<h1 align="center">
  MedModels <br/> Using High-End Machine Learning to Enhance Medical Data Analyses
</h1>

<div align="center">
  <img alt="MedModels Logo" src="https://raw.githubusercontent.com/limebit/medmodels/main/images/medmodels_logo.svg"><br>
</div>

<div align="center">
  <a href="https://black.readthedocs.io/en/stable/">
    <img alt="Code Style" src="https://img.shields.io/badge/code_style-black-black.svg">
  </a>
  <img alt="Python Versions" src="https://img.shields.io/badge/python-3.9%20%7C%203.10-blue">
  <a href="https://github.com/limebit/medmodels/blob/main/LICENSE">
    <img alt="MedModels License" src="https://img.shields.io/github/license/limebit/medmodels.svg">
  </a>
  <a href="https://github.com/limebit/medmodels/actions/workflows/testing.yml">
    <img src="https://github.com/limebit/medmodels/actions/workflows/testing.yml/badge.svg?branch=main" alt="Tests">
  </a>
</div>

## Table of Contents

- [Why do you need MedModels?](#why-do-you-need-medmodels)
- [What is MedModels?](#what-is-medmodels)
- [Who is MedModels aimed at?](#who-is-medmodels-aimed-at)
- [What does MedModels offer?](#what-does-medmodels-offer)
- [How do you get MedModels?](#how-do-you-get-medmodels)

## Why do you need MedModels?

The use of medical data in connection with AI is a rapidly growing field of research.
However, there is a significant gap between the methodology that is published in scientific papers and the techniques that are used in the medical industry. Currently, companies have to adapt the latest findings to their individual set-up. With MedModels, we close this gap by offering all users an intuitive Python framework that provides the methods from current research publications in a directly usable manner.

## What is MedModels?

MedModels is a Python-based software framework for the analysis of real-world evidence data for the healthcare sector. MedModels makes complex analyses and predictions based on medical data significantly faster, more precise, reliable, and more cost-effective.

The vision is to combine the key expertise of research companies and science in order to gain the greatest possible benefit for patients from the data. With MedModels, we close the clear innovation gap between academic research and industrial application by providing the latest scientific methods as an application-oriented framework.

## Who is MedModels aimed at?

MedModels is aimed at a wide range of users, including medical care institutions (e.g., clinics and hospitals), research institutions (e.g., universities and cancer registers), insurance companies (e.g., health insurance and accident insurance), pharmaceutical companies as well as regulatory institutions such as drug administrations.

## What does MedModels offer?

- **Treatment Effect Estimation**
  <br/> Treatment effect estimations are used to compare the effects of treatment and control groups in non-experimental observational studies.
- **Patient Matching**
  <br/> Statistical methods as well as innovative machine learning algorithms help identify similar patients in treatment and control groups to account for confounding variables.
- **Medical Data Synthesis**
  <br/> Generative synthetic patient data closes data gaps and makes representative patient data available while ensuring data privacy.
- **Medical Concept Embeddings**
  <br/> Medical concept embeddings pre-process medical raw data into compact representations that depict temporal and causal relationships of the concepts (e.g., diagnosis, treatment, medications, ...).
- **Predictive Modeling**
  <br/> Machine learning models predict individual patient-level risks (e.g., diagnostics, events, treatment chances, ...) based on EHR data.
- **Explainable AI**
  <br/> Counterfactual explanations and other techniques make black box forecasts comprehensible and interpretable.

## How do you get MedModels?

Limebit hosts the official open source code on GitHub at: [MedModels GitHub Repository](https://github.com/limebit/medmodels)

We recommend to use `pip` to install the latest version of MedModels:

```
pip install medmodels
```

For detailed information on how to use MedModels, please read the [MedModels documentation](https://www.medmodels.de/documentation).

==> medmodels-0.1.1.tar.gz: medmodels-0.1.1/README.md <==
<div align="center">
  <img alt="MedModels Logo" src="https://raw.githubusercontent.com/limebit/medmodels/main/images/medmodels_logo.svg">
</div>

<h1 align="center">
  Using High-End Machine Learning to Enhance Medical Data Analyses
</h1>

<div align="center">
  <a href="https://black.readthedocs.io/en/stable/">
    <img alt="Code Style" src="https://img.shields.io/badge/code_style-black-black.svg">
  </a>
  <img alt="Python Versions" src="https://img.shields.io/badge/python-3.9%20%7C%203.10%20%7C%203.11%20%7C%203.12-blue">
  <a href="https://github.com/limebit/medmodels/blob/main/LICENSE">
    <img alt="MedModels License" src="https://img.shields.io/github/license/limebit/medmodels.svg">
  </a>
  <a href="https://github.com/limebit/medmodels/actions/workflows/testing.yml">
    <img src="https://github.com/limebit/medmodels/actions/workflows/testing.yml/badge.svg?branch=main" alt="Tests">
  </a>
</div>

## Table of Contents

- [Why do you need MedModels?](#why-do-you-need-medmodels)
- [What is MedModels?](#what-is-medmodels)
- [Who is MedModels aimed at?](#who-is-medmodels-aimed-at)
- [What does MedModels offer?](#what-does-medmodels-offer)
- [How do you get MedModels?](#how-do-you-get-medmodels)

## Why do you need MedModels?

The use of medical data in connection with AI is a rapidly growing field of research.
However, there is a significant gap between the methodology that is published in scientific papers and the techniques that are used in the medical industry. Currently, companies have to adapt the latest findings to their individual set-up. With MedModels, we close this gap by offering all users an intuitive Python framework that provides the methods from current research publications in a directly usable manner.

## What is MedModels?

MedModels is a Python-based software framework for the analysis of real-world evidence data for the healthcare sector. MedModels makes complex analyses and predictions based on medical data significantly faster, more precise, reliable, and more cost-effective.

The vision is to combine the key expertise of research companies and science in order to gain the greatest possible benefit for patients from the data. With MedModels, we close the clear innovation gap between academic research and industrial application by providing the latest scientific methods as an application-oriented framework.

## Who is MedModels aimed at?

MedModels is aimed at a wide range of users, including medical care institutions (e.g., clinics and hospitals), research institutions (e.g., universities and cancer registers), insurance companies (e.g., health insurance and accident insurance), pharmaceutical companies as well as regulatory institutions such as drug administrations.

## What does MedModels offer?

- **Treatment Effect Estimation**
  <br/> Treatment effect estimations are used to compare the effects of treatment and control groups in non-experimental observational studies.
- **Patient Matching**
  <br/> Statistical methods as well as innovative machine learning algorithms help identify similar patients in treatment and control groups to account for confounding variables.
- **Medical Data Synthesis**
  <br/> Generative synthetic patient data closes data gaps and makes representative patient data available while ensuring data privacy.
- **Medical Concept Embeddings**
  <br/> Medical concept embeddings pre-process medical raw data into compact representations that depict temporal and causal relationships of the concepts (e.g., diagnosis, treatment, medications, ...).
- **Predictive Modeling**
  <br/> Machine learning models predict individual patient-level risks (e.g., diagnostics, events, treatment chances, ...) based on EHR data.
- **Explainable AI**
  <br/> Counterfactual explanations and other techniques make black box forecasts comprehensible and interpretable.

## How do you get MedModels?

Limebit hosts the official open source code on GitHub at: [MedModels GitHub Repository](https://github.com/limebit/medmodels)

We recommend to use `pip` to install the latest version of MedModels:

```
pip install medmodels
```

For detailed information on how to use MedModels, please read the [MedModels documentation](https://www.medmodels.de/api-reference/latest).
